# eric7.MicroPython.MicroPythonWebreplUrlAddEditDialog

Module implementing a dialog to edit the parameters for a WebREPL connection.

### Global Attributes

None

### Classes

MicroPythonWebreplUrlAddEditDialog | Class implementing a dialog to edit the parameters for a WebREPL connection.

### Functions

None

## MicroPythonWebreplUrlAddEditDialog

Class implementing a dialog to edit the parameters for a WebREPL connection.

### Derived from

QDialog, Ui_MicroPythonWebreplUrlAddEditDialog

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonWebreplUrlAddEditDialog | Constructor
__populateFields | Private method to populate the various dialog fields with the given parameters.
__updateOkButton | Private slot to update the enabled state of the OK button.
getWebreplUrl | Public method to retrieve the entered WebREPL connection data.

### Static Methods

None

#### MicroPythonWebreplUrlAddEditDialog (Constructor)

MicroPythonWebreplUrlAddEditDialog(definedNames, connectionParams=None, parent=None)

Constructor

definedNames (list of str)
  list of already define WebREPL connection names
connectionParams (tuple of (str, str, str) (optional))
  parameters for the WebREPL connection to be edited (default to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### MicroPythonWebreplUrlAddEditDialog.__populateFields

__populateFields(params)

Private method to populate the various dialog fields with the given parameters.

params (tuple of (str, str, str))
  arameters for the WebREPL connection to be edited

#### MicroPythonWebreplUrlAddEditDialog.__updateOkButton

__updateOkButton()

Private slot to update the enabled state of the OK button.

#### MicroPythonWebreplUrlAddEditDialog.getWebreplUrl

getWebreplUrl()

Public method to retrieve the entered WebREPL connection data.

Return:
  tuple containing the name, description, URL and device type for the WebREPL connection

Return Type:
  tuple of (str, str, str, str)

Up